/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: TableServlet.java,v 1.1 2000/07/22 00:44:49 pmahar Exp $
 */

package kelp.webapp.presentation;

import org.enhydra.xml.xmlc.XMLCUtil;

import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.html.HTMLTableElement;
import org.w3c.dom.html.HTMLTableRowElement;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.io.IOException;

/**
 * <p>
 * This presentation object dynamically creates an HTML page
 * showing the greeting from the application configuration file.
 * </p>
 */
public class TableServlet extends HttpServlet {
  private final String[] names =
     {"Travis Shook", "Kelly Rose",  "Lloyd Tabb",
      "David Toth",   "Adam Menkes", "Randy Solton"};
  private TableHTML page = null;

  public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, IOException
    {
    page = createPage();
    response.getWriter().write(page.toDocument());
    response.getWriter().flush();
    response.flushBuffer();
  }

  public TableHTML createPage()  {
    page = new TableHTML();
    fixupTable();
    return page;
  }

  private void fixupTable() {
    HTMLTableElement    table   = page.getElementSampleTable();
    HTMLTableRowElement dataRow = page.getElementDataRow();
    HTMLTableRowElement newRow;
    clearTable(table, dataRow);
    for (int i = 0 ; i < names.length ; i++) {
      newRow = createNewRow(dataRow, i);
      table.appendChild(newRow);
    }
  }

  private HTMLTableRowElement createNewRow(
       HTMLTableRowElement dataRow,  int i) {

    HTMLTableRowElement rowNew   = null;
    Element             dataCell = null;

    rowNew   = (HTMLTableRowElement)dataRow.cloneNode(true);

    dataCell = XMLCUtil.getRequiredElementById("cellOne", rowNew);
    XMLCUtil.getFirstText(dataCell).setData("" + (i + 1));

    dataCell = XMLCUtil.getRequiredElementById("cellTwo", rowNew);
    XMLCUtil.getFirstText(dataCell).setData(names[i]);

    return rowNew;
  }


  /**
   * Delete all table elements that do not have IDs and
   * also delete data row.
  **/
  protected void clearTable(Node node, HTMLTableRowElement dataRow) {
    if (node instanceof HTMLTableRowElement) {
      String id = ((HTMLTableRowElement)node).getId();
      if ((id == null) || (id.length() == 0) || (node == dataRow)) {
        node.getParentNode().removeChild(node);
      }
    } else {
      // Not a row, search children.
      Node child = node.getFirstChild();
      while (child != null) {
        Node next = child.getNextSibling();
        clearTable(child, dataRow);
        child = next;
      }
    }
  }

}


