/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: MetaDataHandlerV3.java,v 1.1 2000/07/19 00:33:55 pmahar Exp $
 */

package org.enhydra.kelp.common.bridge;

// Kelp imports
import org.enhydra.kelp.common.node.OtterXMLCNode;

// XMLC imports
import org.enhydra.xml.xmlc.XMLCException;
import org.enhydra.xml.xmlc.commands.xmlc.XMLCOptions;
import org.enhydra.xml.xmlc.commands.options.OptionsParser;

// Standard imports
import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Array;

public class MetaDataHandlerV3 implements MetaDataHandler {
  private LocalMetaData metaData = null;

  public MetaDataHandlerV3() {
    metaData = new LocalMetaData();
  }


  public String getDocumentOutput() {
     String outPath = null;
     File outFile = metaData.getDocumentOutput();
     if (outFile != null) {
       outPath = outFile.getAbsolutePath();
     }
     return outPath;
  }

  public void setDocumentOutput(String s) {
    invokeSetter("setDocumentOutput","java.io.File", new File(s));
  }

  // Compiler Options
  public boolean getCompileSource() {
    return (! metaData.getNoCompile());
  }
  public void setCompileSource(boolean b) {
    metaData.setNoCompile(! b);
  }

  public String getInputDocument() {
    File doc = null;
    String docPath = new String();
    doc = metaData.getSourceDocument();
    if (doc != null) {
       docPath = doc.getAbsolutePath();
    }
    return docPath;
  }

  public void setInputDocument(String s) {
    File f = new File(s);
    metaData.setSourceDocument(f, true);
  }

  public boolean getKeepGeneratedSource() {
    return metaData.getKeep();
  }

  public void setKeepGeneratedSource(boolean b) {
    metaData.setKeep(b);
  }

  public boolean getPrintAccessorInfo() {
    return metaData.getPrintAccessMethods();
  }

  public void setPrintAccessorInfo(boolean b) {
    metaData.setPrintAccessMethods(b);
  }

  public boolean getPrintDOM() {
    return metaData.getDump();
  }
  public void setPrintDOM(boolean b) {
    metaData.setDump(b);
  }

  public boolean getPrintParseInfo() {
    return metaData.getParseInfo();
  }

  public void setPrintParseInfo(boolean b) {
      metaData.setParseInfo(b);
  }


  public boolean getPrintVersion() {
    return metaData.getPrintVersion();
  }

  public boolean getVerbose() {
    return metaData.getVerbose();
  }

  public void setVerbose(boolean b) {
    metaData.setVerbose(b);
  }

  // Document Class
  public String getClassName() {
    return metaData.getClassName();
  }

  public void setClassName(String n) {
    metaData.setClassName(n);
  }

  public File getJavaClassSource() {
     return metaData.getJavaClassSource();
  }

  public void setJavaClassSource(File f, OtterXMLCNode node) {
    metaData.setJavaClassSource(f);
  }

  public File getJavaInterfaceSource() {
    return metaData.getJavaInterfaceSource();
  }
  public void setJavaInterfaceSource(File f, OtterXMLCNode node) {
    metaData.setJavaInterfaceSource(f);
  }

  public String getPackageName() {
    return metaData.getPackageName();
  }

  public boolean getRecompilation() {
    return metaData.getForRecomp();
  }

  public void setRecompilation(boolean b) {
    invokeSetter("setForRecomp", "boolean", new Boolean(b));
  }


  public void setPrintVersion(boolean b) {
    invokeSetter("setPrintVersion","boolean", new Boolean(b));
  }

  // DOM Edits
  public Object[] getDeleteElements() {
    Object result = new Object();
    result = invokeGetter("getDeleteElementClasses");
    return (Object[]) result;
  }

  public Object[] getURLMappings() {
    Object result = new Object();
    result = invokeGetter("getURLEdits");
    return (Object[]) result;
  }

  // Other
  public Object getMetaData() {
    return metaData;
  }

  public void parse(String[] files, String[] args, PrintWriter writer,
      OtterXMLCNode node)
     throws XMLCException, IOException {

    OptionsParser op  = null;

    metaData.complete();
    if ((files.length > 0)) {
       op = getNewOptionsParser();
       callParse(op, files);
     }
     if ((args.length > 0)) {
       if (op == null) {
         op = getNewOptionsParser();
       }
       callParse(op, args);
     }
  }


  public void save(File op) throws IOException {
     if (! op.getParentFile().exists()) {
        op.getParentFile().mkdirs();
     }
     invokeSetter("save","java.io.File",op);
  }


  /// private stuff
  private Object invokeGetter(String methodName) {
    Class[] types = new Class[0];
    Object[] values = new Object[0];
    Object result = new Object();
    Method meth = null;
    try {
      meth = metaData.getClass().getMethod(methodName, types);
      result = meth.invoke(metaData, values);
    } catch (Exception e) {
      e.printStackTrace();
    }
    return result;
  }


  private void invokeSetter(String methodName, String typeName, Object value) {
    Class[] types = new Class[1];
    Object[] values = new Object[1];
    Method meth = null;
    try {
      types[0] = Class.forName(typeName);
      values[0] = value;
      meth = metaData.getClass().getMethod(methodName, types);
      meth.invoke(metaData, values);
    } catch (Exception e) {
      e.printStackTrace();
    }
  }


   private OptionsParser getNewOptionsParser() {
        OptionsParser parser = null;

        try {
            Class         opClass =
                Class.forName("org.enhydra.xml.xmlc.commands.options.OptionsParser");
            Constructor[] opCon = opClass.getConstructors();
            Class[]       params = opCon[0].getParameterTypes();
            Object[]      values = new Object[0];

            if (params.length == 1) {
                values = new Object[1];
                values[0] = metaData;
            }
            parser = (OptionsParser) opCon[0].newInstance(values);
        } catch (Exception e) {
            parser = null;
            e.printStackTrace();
        }
        return parser;
    }

    private void callParse(OptionsParser parser,
                           String[] args) throws IOException, XMLCException {
        Class    opClass = parser.getClass();
        Class[]  params = new Class[1];
        Object[] values = null;
        Method   method = null;

        params[0] = args.getClass();
        try {
            method = opClass.getMethod("parse", params);
            values = new Object[1];
            values[0] = args;
            method.invoke(parser, values);
        } catch (InvocationTargetException e) {
            if (e.getTargetException() instanceof IOException) {
                throw (IOException) e.getTargetException();
            } else if (e.getTargetException() instanceof XMLCException) {
                throw (XMLCException) e.getTargetException();
            } else {
                e.printStackTrace();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        // op.parse(args); // 3.0
        // op.parse(options, args); //2.3
    }




    /**
     * Class declaration
     *
     *
     * @author
     * @version %I%, %G%
     */
    public class LocalMetaData extends XMLCOptions {
        private File javaClassSource = null;
        private File javaInterfaceSource = null;
        private File sourceDoc = null;

        /**
         * Method declaration
         *
         *
         * @param f
         *
         * @see
         */
        public void setJavaClassSource(File f) {
            javaClassSource = f;
        }

        public void setJavaInterfaceSource(File f) {
           javaInterfaceSource = f;
        }

        /**
         * Method declaration
         *
         *
         * @return
         *
         * @see
         */
        public File getJavaClassSource() {
            return javaClassSource;
        }

        public File getJavaInterfaceSource() {
           return javaInterfaceSource;
        }

        /**
         * Method declaration
         *
         *
         * @param f
         * @param real
         *
         * @see
         */
        public void setSourceDocument(File f, boolean real) {
            if (real) {
                sourceDoc = f;
                setSourceDocument(sourceDoc);
            }
        }

        /**
         * Method declaration
         *
         *
         * @param f
         *
         * @see
         */
        public void setSourceDocument(File f) {
            super.setSourceDocument(sourceDoc);
        }

        /**
         * Method declaration
         *
         *
         * @return
         *
         * @see
         */
        public File getSourceDocument() {
            return sourceDoc;
        }

    }

}