/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: XMLCBuildDialog.java,v 1.3 2000/07/28 01:03:13 pmahar Exp $
 */

package org.enhydra.kelp.common.wizard.xmlc;

import org.enhydra.kelp.KelpVersion;
import org.enhydra.kelp.common.capture.Writer;
import org.enhydra.kelp.common.capture.WriteEvent;
import org.enhydra.kelp.common.capture.WriteListener;
import org.enhydra.kelp.common.node.OtterProject;
import org.enhydra.kelp.common.node.OtterXMLCNode;
import org.enhydra.kelp.common.wizard.AbstractBuildDialog;
import org.enhydra.kelp.common.swing.AboutBox;
import org.enhydra.kelp.common.swing.SwingUtil;
import org.enhydra.xml.xmlc.XMLCVersion;
import javax.swing.*;
import java.beans.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * This class defines the main dialog for the XMLC Wizard.
 *
 * @author
 * Paul Mahar
 * @version %I%, %G%
 */
public class XMLCBuildDialog extends AbstractBuildDialog {
    private boolean		standalone = false;
    private XMLCPropertyPanel	propertyPanel;
    private XMLCBuildThread     buildThread = null;

    /**
     * Create the dialog as a child of a frame.
     *
     * @param owner
     * The parent Frame used when the dialog is modal.
     * @param title
     * The title for the dialog.
     * @param modal
     * Normally this is set to true for wizards.
     */
    public XMLCBuildDialog(Frame owner, String title, boolean modal) {
	super(owner, title, modal);
        construct();
    }

    /**
     * Create the dialog as a child of another dialog.
     *
     * @param owner
     * The parent Dialog used when the dialog is modal.
     * @param title
     * The title for the dialog.
     * @param modal
     * Normally this is set to true for wizards.
     */
    public XMLCBuildDialog(Dialog owner, String title, boolean modal) {
	super(owner, title, modal);
       construct();
   }

   public XMLCBuildDialog(Frame owner) {
     super(owner);
     construct();
   }


    private void construct() {
        try {
          propertyPanel = (XMLCPropertyPanel) Beans.instantiate(getClass().getClassLoader(),
					       XMLCPropertyPanel.class.getName());
          init(propertyPanel);
        } catch (Exception e) {
            e.printStackTrace();
        }
        buttonMake.setText("Compile");
    }

    public static void main(String[] args) {
	SwingUtil.setLookAndFeelToSystem();

	XMLCBuildDialog dlg = new XMLCBuildDialog(new Frame(), "title", true);

	dlg.show();
	System.out.println("Done");
	System.exit(0);
    }


    /**
     * Method declaration
     *
     *
     * @see
     */
    public void make() {
        if (buildThread != null) {
            buildThread.expire();
        }

        WriteListener[] wl = new WriteListener[getWriteListeners().size()];

        for (int i = 0; i < getWriteListeners().size(); i++) {
            wl[i] = (WriteListener) getWriteListeners().elementAt(i);
        }

        buildThread = new XMLCBuildThread(wl);
        buildThread.setProject(getProject());
        buildThread.setNodes(getProject().getAllXMLCNodes());
        buildThread.start();
    }

    public void setProject(OtterProject project) {
       super.setProject(project);
       super.setNodes(project.getAllXMLCNodes());
    }



}
