/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: PrimeNodeFactory.java,v 1.5 2000/07/21 19:53:03 pmahar Exp $
 */
package org.enhydra.kelp.jbuilder.node;

// Kelp imports
import org.enhydra.kelp.common.node.OtterNode;
import org.enhydra.kelp.common.node.OtterNodeFactory;
import org.enhydra.kelp.common.node.OtterProject;
import org.enhydra.kelp.common.node.OtterTemplateNode;
import org.enhydra.kelp.common.node.OtterFolderNode;
import org.enhydra.kelp.common.node.OtterHTMLFileNode;
import org.enhydra.kelp.common.node.OtterImageFileNode;
import org.enhydra.kelp.common.node.OtterJavaFileNode;
import org.enhydra.kelp.common.node.OtterTextFileNode;
import org.enhydra.kelp.common.node.OtterWMLFileNode;

// Primetime imports
import com.borland.primetime.node.Node;
import com.borland.primetime.node.FileNode;
import com.borland.primetime.node.FolderNode;
import com.borland.jbuilder.node.JBProject;

// Standard imports
import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class PrimeNodeFactory extends OtterNodeFactory {

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param name
     *
     * @return
     *
     * @see
     */
    public OtterFolderNode createFolderNode(OtterProject otterProject,
                                            OtterNode otterNode,
                                            String name) {
        OtterFolderNode folder = null;
        FolderNode      nativeFolder = null;

        // check if exists
        JBProject       nativeProject =
            (JBProject) otterProject.getNativeProject();
        Node[]          nativeChild = nativeProject.getChildren();

        for (int i = 0; i < nativeChild.length; i++) {
            if (nativeChild[i] instanceof FolderNode) {
                nativeFolder = (FolderNode) nativeChild[i];
                if (nativeFolder.getName().trim().equalsIgnoreCase(name.trim())) {
                    folder = new PrimeFolderNode(nativeFolder);
                }
            }
        }
        if (folder == null) {
            folder = new PrimeFolderNode(otterProject, otterNode, name);
        }
        return folder;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterJavaFileNode createJavaFileNode(OtterProject otterProject,
                                                OtterNode otterNode,
                                                String file) {
        OtterJavaFileNode javaFile = new PrimeJavaFileNode(otterProject,
                otterNode, file);

        return javaFile;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterHTMLFileNode createHTMLFileNode(OtterProject otterProject,
                                                OtterNode otterNode,
                                                String file) {
        OtterHTMLFileNode html = new PrimeHTMLFileNode(otterProject,
                otterNode, file);

        return html;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterWMLFileNode createWMLFileNode(OtterProject otterProject,
                                              OtterNode otterNode,
                                              String file) {
        OtterWMLFileNode node = new PrimeWMLFileNode(otterProject, otterNode,
                file);

        return node;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterImageFileNode createImageFileNode(OtterProject otterProject,
            OtterNode otterNode, String file) {
        OtterImageFileNode image = new PrimeImageFileNode(otterProject,
                otterNode, file);

        return image;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterTextFileNode createTextFileNode(OtterProject otterProject,
                                                OtterNode otterNode,
                                                String file) {
        OtterTextFileNode text = new PrimeTextFileNode(otterProject,
                otterNode, file);

        return text;
    }

    /**
     * Method declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @return
     *
     * @see
     */
    public OtterTemplateNode createTemplateNode(OtterProject otterProject,
            OtterNode otterNode, String file) {
        OtterTemplateNode template = null;
        template = new PrimeTemplateNode(otterProject,
                otterNode, file);

        return template;
    }

    /**
     * Method declaration
     *
     *
     * @param project
     * @param node
     * @param files
     *
     * @return
     *
     * @see
     */
    public OtterJavaFileNode[] replaceGeneratedSource(OtterProject project,
            OtterNode node, String[] files) {

        // Remove previously generated sources and then add
        OtterJavaFileNode[] javaNodes = new OtterJavaFileNode[files.length];
        JBProject           nativeProject =
            (JBProject) project.getNativeProject();
        FileNode            nativeNode = (FileNode) node.getNativeNode();
        Node[]              child = nativeNode.getChildren();
        FileNode            fn = null;
        File                current = null;
        boolean             keep = false;

        for (int i = 0; i < child.length; i++) {
            if (child[i] instanceof FileNode) {
                fn = (FileNode) child[i];
                for (int j = 0; j < files.length; j++) {
                    current = new File(files[j]);
                    if (fn.getUrl().getFileObject().getAbsolutePath().equals(current.getAbsolutePath())) {
                        keep = true;
                        break;
                    }
                }
                if (!keep) {
                    fn.getUrl().getFileObject().delete();
                    child[i].setParent(null);
                }
            }
        }
        try {
            nativeNode.save();
        } catch (Exception e) {
            e.printStackTrace();
        }
        nativeNode.check();
        nativeProject.fireChildrenChanged(nativeNode);
        nativeProject.check();
        try {
            nativeProject.save();
        } catch (Exception e) {
            e.printStackTrace();
        }
        for (int i = 0; i < files.length; i++) {
            javaNodes[i] = createJavaFileNode(project, node, files[i]);
        }
        return javaNodes;
    }

}

