/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: XMLCProperties.java,v 1.3 2000/07/24 07:24:41 pmahar Exp $
 */

package org.enhydra.kelp.jbuilder.properties;

// Kelp imports
import org.enhydra.kelp.common.swing.SwingUtil;
import org.enhydra.kelp.jbuilder.node.PrimeHTMLFileNode;
import org.enhydra.kelp.common.node.OtterXMLCNode;

// JBuilder Foundation imports
import com.borland.jbuilder.node.HTMLFileNode;
import com.borland.primetime.ide.Browser;
import com.borland.primetime.node.Node;
import com.borland.primetime.node.LightweightNode;
import com.borland.primetime.node.TextFileNode;
import com.borland.primetime.node.Project;
import com.borland.primetime.properties.PropertyPageFactory;
import com.borland.primetime.properties.PropertyPage;
import com.borland.primetime.properties.PropertyManager;
import com.borland.primetime.properties.PropertyGroup;

public class XMLCProperties implements PropertyGroup {

  public static final String GENERATE_CLASS = "Generate";

  public XMLCProperties() {
  }


  /**
   * Initialize this OpenTool
   */
  public static void initOpenTool(byte majorVersion, byte minorVersion) {
	PropertyManager.registerPropertyGroup(new XMLCProperties());
  }

  /**
   * Returns a PropertyPageFactory for the project or for an
   * HTMLFileNode. Null if topic is something else.
   *
   * TODO: ?? Add XMLFileNode ??
   */
  public PropertyPageFactory getPageFactory(final Object topic) {
    PropertyPageFactory factory = null;
    Project project = null;

    if (topic instanceof TextFileNode) {
      TextFileNode textNode = (TextFileNode) topic;
      project = textNode.getProject();
      if (project == null) {
      	 // Skip
      } else if (textNode.getUrl().getFileExtension().equalsIgnoreCase("wml") ||
                 textNode instanceof HTMLFileNode) {
        // Node property page to set your XMLC properties
        factory = (new PropertyPageFactory("Enhydra XMLC") {
          public PropertyPage createPropertyPage() {
            return new XMLCNodePropertyPage(topic);
          }
        });
      }
    } else if (topic instanceof LightweightNode) {
        // Package or Folder node
        LightweightNode lightNode = null;
        lightNode = (LightweightNode) topic;
        project = lightNode.getProject();
        if (project == null) {
       	   // Skip
        } else {
          factory = (new PropertyPageFactory("Enhydra XMLC") {
            public PropertyPage createPropertyPage() {
              return new XMLCPackagePropertyPage(topic);
            }
          });
        }
    } else if (topic instanceof Project) {
        // Project property page to set your XMLC properties
        factory = (new PropertyPageFactory("Enhydra XMLC") {
          public PropertyPage createPropertyPage() {
            return new XMLCProjectPropertyPage(topic);
          }
        });
    }
    return factory;
  }

  public void initializeProperties() {
  }
}