/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: OracleWMLFileNode.java,v 1.1 2000/05/16 09:23:51 pmahar Exp $
 */


package org.enhydra.kelp.jdeveloper.node;

// Kelp imports
import org.enhydra.kelp.common.node.OtterWMLFileNode;
import org.enhydra.kelp.common.node.OtterNode;
import org.enhydra.kelp.common.node.OtterResourceNode;
import org.enhydra.kelp.common.node.OtterSelectionNode;
import org.enhydra.kelp.common.node.OtterProject;
import org.enhydra.kelp.common.PropUtil;
// JDeveloper imports
import borland.jbuilder.addin.Node;
import borland.jbuilder.addin.Project;
import borland.jbuilder.addin.Url;
// Standard imports
import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class OracleWMLFileNode extends OracleNode implements OtterWMLFileNode {
    private Exception exception = null;

    public OracleWMLFileNode(Node n) {
        super(n);
    }

    /**
     * Constructor declaration
     *
     *
     * @param otterProject
     * @param otterNode
     * @param file
     *
     * @see
     */
    public OracleWMLFileNode(OtterProject otterProject, OtterNode otterNode,
			   String file) {
	Node    nativeNode = null;
	Project nativeProject = null;
	Url     url = null;

	if (otterProject.getNativeProject() instanceof Project) {
	    nativeProject = (Project) otterProject.getNativeProject();
	}

	url = new Url(file);
	nativeNode = nativeProject.createNode(url, true);

	nativeProject.addNode(nativeNode);
	setNativeNode(nativeNode);
    }

  public boolean isSelected() {
   String  in = getProperty(OtterSelectionNode.SELECTED);
   return PropUtil.stringToBoolean(in, false);
  }

  public void setSelected(boolean b) {
	setProperty(OtterSelectionNode.SELECTED,
	   PropUtil.booleanToString(b));
        if (b) {
          setStatic(false);
          // both may be false, but only can one true
        }
  }

  public boolean isStatic() {
   String  in = getProperty(OtterResourceNode.RESOURCE_STATIC);
   return PropUtil.stringToBoolean(in, false);
  }

  public void setStatic(boolean b) {
	setProperty(OtterResourceNode.RESOURCE_STATIC,
	   PropUtil.booleanToString(b));
        if (b) {
          setSelected(false);
        }
  }


    /**
     * Save Exception information for reporting. This lets exceptions from
     * multiple nodes to be reported in a batch.
     *
     * @param e
     * An exception that occured while invoking XMLC.
     */
    public void setException(Exception e) {
	exception = e;
    }

    /**
     * Get an exception that occured when invoking XMLC. Null if the node
     * has not been compiled or was compiled without error.
     */
    public Exception getException() {
	return exception;
    }



  public void preCompile() {
    // nothing to do
  }

}
