/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: ConfWizard.java,v 1.5 2000/08/01 01:55:02 pmahar Exp $
 */

package org.enhydra.kelp.jdeveloper.wizard.conf;

import org.enhydra.kelp.common.swing.IconSet;
import org.enhydra.kelp.common.swing.SwingUtil;
import org.enhydra.kelp.common.wizard.conf.ConfBuildDialog;
import org.enhydra.kelp.common.node.OtterProject;
import org.enhydra.kelp.common.node.OtterTemplateNode;
import org.enhydra.kelp.jdeveloper.node.OracleProject;
import org.enhydra.kelp.jdeveloper.node.OracleTemplateNode;
import borland.jbuilder.addin.Container;
import borland.jbuilder.addin.Context;
import borland.jbuilder.addin.IdeEnvironment;
import borland.jbuilder.addin.VersionedAddin;
import borland.jbuilder.addin.Wizard;
import borland.jbuilder.addin.WizardManager;
import borland.jbuilder.addin.Node;
import borland.jbuilder.addin.HtmlNode;
import borland.jbuilder.addin.Project;
import javax.swing.JOptionPane;
import java.awt.Component;
import java.awt.Dialog;
import java.awt.Frame;
import java.awt.Image;
import java.io.File;
import java.io.Serializable;
import java.util.Vector;
import java.lang.System;

/**
 * This is the class that gets registered with the IDE through the
 * jbuilder.properties file.
 */
public class ConfWizard implements Serializable, VersionedAddin, Wizard {
    private String       title      =  null;
    private Vector       nodeVector = new Vector();
    private int		 option     = 0;

    /**
     * Constructor declaration
     *
     *
     * @see
     */
    public ConfWizard() {}

    /**
     * For the VersionAddin Interface.
     */
    public String version() {
	return "2.0";
    }

    /**
     * Entry point exposed by the Wizard interface for early initialization.
     * Registers this Wizard object with the IDE's WizardManager object
     * @$param ide Access to all AddIn interfaces
     */
    public void startup(IdeEnvironment ide) {
	WizardManager e = ide.getWizardManager();

	e.registerWizard(this);
    }

    /**
     * Wizard interface implementation, run the wizard in response to this call.
     * @param ide Access to all AddIn interfaces
     * @param context Current node, project, browser
     */
    public void invoke(IdeEnvironment ide, Context context) {
	Project             nativeProject = null;
	OtterTemplateNode[] templateNodes     = null;
	Frame	            frame         = null;

	frame         = ide.getIdeFrame();
	nodeVector    = new Vector();
	nativeProject = context.getProject();

        String ver = System.getProperty("java.version");
        if (ver.startsWith("1.1")) {
          JOptionPane.showMessageDialog(ide.getIdeFrame(),
                                        "Kelp requires Java 2.\n" +
                                        "Found version: " + ver);
          nativeProject = null;
        }

	if (nativeProject != null
		&& isEnhydraAvailable(ide, nativeProject.getClassPath())) {
	    nativeProject.save(false);    // save all file changes in project
	    readNodes(nativeProject);

	    ConfBuildDialog dlg = new ConfBuildDialog(frame, getName(), true);

	    templateNodes = new OtterTemplateNode[nodeVector.size()];

	    for (int i = 0; i < templateNodes.length; i++) {
		templateNodes[i] = (OtterTemplateNode) nodeVector.elementAt(i);
	    }

	    OtterProject otterProject = null;

	    otterProject = new OracleProject(nativeProject);

	    dlg.setProject(otterProject);
	    dlg.setNodes(templateNodes);


	    dlg.show();
	    frame.requestFocus();
	}
    }

    /**
     * Wizard interface method, returns information about the type of Wizard this is.
     * @return An integer representing combined flags defined by the
     * Wizard interface.
     */
    public int getInfo() {
	return Wizard.PRODUCES_FILE + Wizard.REQUIRES_PROJECT;
    }

    /**
     * Wizard interface method, returns the name of this wizard.
     * @return Name of the wizard
     */
    public String getName() {
	return "Local Deployment";
    }

    /**
     * Wizard interface method, returns the text for the menu label
     * @return Menu label text
     */
    public java.lang.String getMenuLabel() {
	return getName() + "...";
    }

    /**
     * Wizard interface method
     * @return Currently returns no image (null)
     */
    public Image getSmallImage() {
	return IconSet.getSmallIcon().getImage();
    }

    /**
     * Wizard interface method
     * @return Currently returns no image (null)
     */
    public Image getBigImage() {
	return IconSet.getLargeIcon().getImage();
    }

    // ?4Paul: Are we keeping entry through showDialog()?

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getTitle() {
	return this.title;
    }

    /**
     * Method declaration
     *
     *
     * @param newTitle
     *
     * @see
     */
    public void setTitle(String newTitle) {
	this.title = newTitle;
    }

    // read only properties

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public int getOption() {
	return option;
    }

    /**
     * Method declaration
     *
     *
     * @param newOption
     *
     * @see
     */
    private void setOption(int newOption) {
	option = newOption;
    }

    /**
     * Method declaration
     *
     *
     * @param owner
     *
     * @see
     */
    public void showDialog(Component owner) {
	ConfBuildDialog dialog = null;

	if (owner instanceof Dialog) {
	    dialog = new ConfBuildDialog((Dialog) owner, getTitle(), true);
	} else if (owner instanceof Frame) {
	    dialog = new ConfBuildDialog((Frame) owner, getTitle(), true);
	}

	dialog.show();
	dialog.clearAll();

	if (owner.isVisible()) {
	    owner.requestFocus();
	}
    }

    /**
     * Method declaration
     *
     *
     * @param args
     *
     * @see
     */
    public static void main(String[] args) {
	SwingUtil.setLookAndFeelToSystem();

	ConfWizard wizard;

	wizard = new ConfWizard();

	wizard.showDialog(new Frame());
	System.exit(0);
    }

    /**
     * Method declaration
     *
     *
     * @param ide
     * @param projectClassPath
     *
     * @return
     *
     * @see
     */
    private boolean isEnhydraAvailable(IdeEnvironment ide,
				       String projectClassPath) {
	String       message = null;

	if (message == null) {
	    if (projectClassPath.toLowerCase().indexOf("enhydra.jar") < 0) {
		message =
		    "The enhydra.jar file is not included in the "
		    + "current project library set.\n"
		    + "Select the Project | Properties menu "
		    + "to add it before using opening the "
                    + "Enhydra Configure wizard.\n\n";
	    }
	}

	if (message != null) {
	    JOptionPane.showMessageDialog(null, message);
	}

	return (message == null);
    }

    // recursively read through nodes.

    /**
     * Method declaration
     *
     *
     * @param container
     *
     * @see
     */
    private void readNodes(Container container) {
	String     filename = null;
	Node[]     nativeNodes = container.getChildren();
	File       current = null;


	for (int i = 0; i < nativeNodes.length; i++) {
	    if (nativeNodes[i] instanceof Container) {
		if (!nativeNodes[i].toString().equalsIgnoreCase("RootContainer")) {
		    readNodes((Container) nativeNodes[i]);    // recrusive folder read.
		}
	    } else {
		filename = nativeNodes[i].getFilename();
		current = new File(filename);
                if ((filename.toLowerCase().endsWith(".conf.in")) &&
	            current.exists()) {
                    OtterTemplateNode templateNode = null;
                    templateNode  = new OracleTemplateNode(nativeNodes[i]);
		    nodeVector.addElement(templateNode);
		}
	    }
	}
    }
}

